- data
a dataframe of residence events. Residence events must include
tag ID, start time, end time, and duration.
- type
the method used to generate the residence events. Options are
"mort", "actel", "glatos", "vtrack", or "manual". If "manual", then user
must specify res.start, res.end, residences, and units.
- ID
a string of the name of the column in data that holds the tag or
sample IDs.
- station
a string of the name of the column in data that holds the
station name or receiver location.
- res.start
a string of the name of the column in data that holds the
start date and time. Must be specified and in POSIXt or character in the format
YYYY-mm-dd HH:MM:SS if type="manual".
- res.end
a string of the name of the column in data that holds the
end date and time. Must be specified and in POSIXt or character in the format
YYYY-mm-dd HH:MM:SS if type="manual".
- residences
a character string with the name of the column in data
that holds the duration of the residence events.
- units
Units of the duration of the residence events in data. Options are "secs",
"mins", "hours", "days", and "weeks".
- season.start
the start date/time(s) of the period of interest. If the
period of interest is the same in all study years, must be a character string
in format "dd-mm". Otherwise, must be in POSIXt, or a character string in
format YYYY-mm-dd HH:MM:SS.
- season.end
the end date/time(s) of the period of interest. If the
period of interest is the same in all study years, must be a character string
in format "dd-mm". Otherwise, must be in POSIXt, or a character string in
format YYYY-mm-dd HH:MM:SS.
- overlap
option to include residence events that overlap either the
beginning or the end of the period of interest. If TRUE, the full overlapping
residence events will be retained. If FALSE, only the portion of the
residence events that is within the period of interest will be retained,
and residences will be recalculated, using specified units.
Default is TRUE.
- verbose
option to display updates and progress bars as
functions is run. Default is TRUE.